![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/LSSTDESC/tables_io)
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/LSSTDESC/tables_io/smoke-test.yml)
![Read the Docs](https://img.shields.io/readthedocs/tables-io)

[![Template](https://img.shields.io/badge/Template-RAIL%20Specific%20Fork%20LINCC%20Frameworks%20Python%20Project%20Template-brightgreen)](https://github.com/LSSTDESC/RAIL-project-template/tree/main)

# tables_io

Input/output and conversion interfaces for tabular data formats used in DESC analysis pipelines.


## People

* [Eric Charles](https://github.com/LSSTDESC/qp/issues/new?body=@eacharles) (SLAC)


## License, Contributing etc

The code in this repo is available for re-use under the MIT license.

See [read the docs](https://tables-io.readthedocs.io/en/latest/index.html)